@@ -135,14 +135,6 @@ class arduino(_serial_tools.arduino_base):
         # Plot raw
         self.tab_raw.new_autorow()
 
-        # self.button_raw_show_plot = self.tab_raw.add(_g.Button(
-        #     '^^^^^^^', checkable=True, checked=True,
-        #     autosettings_path = name+'.button_raw_show_plot',
-        #     signal_toggled    = self._button_raw_show_plot_toggled,
-        #     tip='Show / hide the plot.'), alignment=0)
-
-        # self.tab_raw.new_autorow()
-
         self.tab_raw.plot = self.tab_raw.add(_g.DataboxPlot(
             autosettings_path = name+'.tab_raw.plot',
             name              = name+'.tab_raw.plot',
@@ -157,8 +149,6 @@ class arduino(_serial_tools.arduino_base):
 
         ####### BIAS
 
-        #self.grid_cal_state.add(_g.Label('BIAS')).set_style(header_style)
-
         self.grid_cal_state.add(_g.Label('Bias Setpoint:'), alignment=2)
         self.number_bias_setpoint = self.grid_cal_state.add(_g.NumberBox(
             value=0.0, step=1, bounds=(0,70), decimals=4, suffix='V',
@@ -240,14 +230,27 @@ class arduino(_serial_tools.arduino_base):
 
 
 
-        # Plot raw
+        # Plot row
         self.tab_cal.new_autorow()
+        self.grid_settings = self.tab_cal.add(_g.GridLayout(margins=False))
 
         # Settings
-        sr = self.settings = self.tab_cal.settings = self.tab_cal.add(_g.TreeDictionary(
+        sr = self.settings = self.tab_cal.settings = self.grid_settings.add(_g.TreeDictionary(
             autosettings_path = name+'.tab_cal.settings',
             name              = name+'.tab_cal.settings',
-            new_parameter_signal_changed=self._settings_cal_changed)).set_width(230)
+            new_parameter_signal_changed=self._settings_cal_changed),
+            column_span=3).set_width(240)
+
+        self.grid_settings.set_column_stretch(2)
+
+        self.grid_settings.new_autorow()
+        self.button_save_settings = self.grid_settings.add(_g.Button('Save Settings')).set_width(100)
+        self.button_load_settings = self.grid_settings.add(_g.Button('Load Settings')).set_width(100)
+
+        # Signals
+        self.button_save_settings.signal_clicked.connect(self._button_save_settings_clicked)
+        self.button_load_settings.signal_clicked.connect(self._button_load_settings_clicked)
+
 
         if not enable_settings_edit: sr.disable()
 
@@ -284,7 +287,7 @@ class arduino(_serial_tools.arduino_base):
         sr.add('Vent_Valve/Gain_LPF', 6.783,
                tip='Gain from the (active) low-pass filter on the PWM output.\nPercentage Open = Scale*(V_PWM2 * Gain_LPF - V_offset)')
 
-        sr.add('Vent_Valve/V_offset', 0, suffix='V',
+        sr.add('Vent_Valve/V_offset', 0.0, suffix='V',
                tip='Offset from transistor emitter-follower after low-pass filter.\nPercentage Open = Scale*(V_PWM2 * Gain_LPF - V_offset)')
 
 
@@ -295,6 +298,7 @@ class arduino(_serial_tools.arduino_base):
             show_logger       = True), alignment=0)
 
 
+
         ######################################
         ## OTHER STUFF
 
@@ -308,6 +312,19 @@ class arduino(_serial_tools.arduino_base):
 
         self.window.show(block)
 
+    def _button_save_settings_clicked(self, *a):
+        """
+        Someone wants to save the settings.
+        """
+        self.settings.save(path='ask', short_keys=True, include_expanded=False, 
+                           filters='*.settings', force_extension=True)
+
+    def _button_load_settings_clicked(self, *a):
+        """
+        Someone wants to load settings.
+        """
+        self.settings.load('ask', filters='*.settings')
+
     def _button_vent_close_clicked(self, *a):
         """
         Close the vent.
@@ -563,7 +580,7 @@ class arduino(_serial_tools.arduino_base):
         """
         Called when one of the cal settings changes.
         """
-        print(a)
+        #print(a)
 
     def get_bias_from_V1(self, V1):
         """
@@ -734,6 +751,6 @@ class arduino(_serial_tools.arduino_base):
 
 
 if __name__ == '__main__':
-    _egg.clear_egg_settings()
-    self = arduino()
+    #_egg.clear_egg_settings()
+    self = arduino(enable_settings_edit=False)
     #self.button_connect(True)
\ No newline at end of file
